<?PHP
    // ***********************************************************************************
    // LMO-Spieltag
    // ***********************************************************************************
    // Copyright etc. spare ich mir.
    // Bitte eMehl an mich, wer's einsetzt.
    // Fr Verbesserungsvorschlge immer offen, Script ist noch nicht perfekt.
    // ***********************************************************************************
    // Liga-Manager Online von Frank Hollwitz
    // http://www.hollwitz.de
    // by: Peter Scherb, 12/2002
    // Anschauen: www.peterscherb.de/svj
    // ***********************************************************************************
    // LMO_SPIELTAG.PHH
    // ***********************************************************************************
    // Funktion:
    // -----------------------------------------------------------------------------------
    // Anzeige des aktuellen, letzten, nchsten Spieltage als Funktion
    // ***********************************************************************************
    // Beschreibung:
    // -----------------------------------------------------------------------------------
    // Anzeige des aktuellen, letzten, nchsten Spieltage mit Einstellmglichkeiten
    // (siehe Einstellungsbereich)
    //
    // ***********************************************************************************
    // Aufruf:
    // -----------------------------------------------------------------------------------
    // ZeigeSpieltag([Art], [LigaFile], [Anzahl_der_Spieltage], [Mannschaften])
    //
    // Art: 1 = Einzelne Liga, LigaFile = Name der Liga mit Pfad, relativ zum Script
    //      2 = Ligen, die sich in der Datei LigaFile befinden
    //
    // LigaFile: Je nach Art, einzelnes Liga-File oder Datei mit den auszugebenden Ligen
    //
    // Anzahl_der_Spieltage: < 0 = die vergangenen Spieltag
    //                         0 = aktueller Spieltag
    //                       > 0 = die nchsten Spieltag
    //
    // Mannschaften: bei Art=1 String mit den auszugebenden Mannschaften, durch ;
    //               getrennt
    //               bei Art=2 "Alle" oder ""
    //
    // Aufbau von LigaFile bei Art = 2:
    //
    // [Name_des_LigaFiles_incl_Pfad 1];[Mannschaft_1][;Mannschaft_2][;... Mannschaft_n]
    // [Name_des_LigaFiles_incl_Pfad 2];[Mannschaft_1][;Mannschaft_2][;... Mannschaft_n]
    //                :
    //                :
    // [Name_des_LigaFiles_incl_Pfad n];[Mannschaft_1][;Mannschaft_2][;... Mannschaft_n]
    // ***
    //
    // Dateiendekennzeichen: ***, kann ber $EndeKennz eingestellt werden
    //
    // steht // am Anfang der Zeile, ist dies eine Kommentarzeile
    // auch kann die lmo_viewer-Steuerdatei dazu benutzt werden.
    //
    // Ist die Variable $makeShortName auf 1 gesetzt, werden Kurznamen angezeigt.
    // Diese werden in der Funktion MakeShortName() generiert.
    // Dabei wird nach folgendem Schema vorgegangen:
    // 1. Definition des Ausschlu-Array's (erweiterbar)
    // 2. Aufdrseln des Namens in ein Array, anhand der Leerzeichen
    // 3. Eliminieren der bereinstimmungen mit dem Auschlu-Array
    // 4. Eliminieren aller Namens-Teile der Lnge <= 2 (z.B. FC, 04, usw.)
    // 5. Sortierung des Array's, anhand der Funktion vglFunc, nach der Lnge
    //    des Strings, lngere zuerst (kann umgedreht werden), wobei Zahlen ganz oben
    //    eingefgt werden
    // 6. Rckgabe des 1. Arrayelements
    //
    // ******************************************************
    // Wen's interessiert, hier der Aufbau des Ergebnis-Array
    // ******************************************************
    //   [0] : Name der Liga
    //   [1] : Anzahl Mannschaften
    //   [2] : Anzahl Spieltage
    //   [3] : Spiele / Spieltag
    //   [4] : Nr. des Favoriten
    //   [5] : Spielende offen
    //   [6] : Reserviert
    //   [7] : Reserviert
    //   [8] : Reserviert
    //   [9] : Reserviert
    //  [10] : Reserviert

    //  [$intOffset] bis [$intOffset]+[1]-1: Mannschaften
    //  [$intOffset] + [1]     : Beginn Spieltag     $spStart
    //  [$intOffset] + [1] +  1: Nr. Spieltag
    //  [$intOffset] + [1] +  2: Datum1
    //  [$intOffset] + [1] +  3: Datum2
    //  [$intOffset] + [1] +  4: Heimmannschaft   --
    //  [$intOffset] + [1] +  5: Gastmannschaft     |
    //  [$intOffset] + [1] +  6: Heimtore           |
    //  [$intOffset] + [1] +  7: Gasttore           |-- Multiplizert mit [3], $spAnzDaten
    //  [$intOffset] + [1] +  8: Notiz              |
    //  [$intOffset] + [1] +  9: Anstozeit         |
    //  [$intOffset] + [1] + 10: Penalty oder Verl. |
    //  [$intOffset] + [1] + 11: Reserviert         |
    //  [$intOffset] + [1] + 12: Reserviert         |
    //  [$intOffset] + [1] + 13: Reserviert       --
    //
    // Daraus ergibt sich die Formel fr die Berechnung eines beliebigen Spieltags:
    // $intOffset + [1] + (NrSpTag - 1) * (3 + (6 * [3])) : Beginn des nchsten Spieltages
    // |                   |                |    |
    // |                   |                |    Heim-, Gastmannsch., Heim-, Gasttore, Notiz, Anstozeit
    // |                   |                Nr, Datum1, Datum2
    // |                  Nr. des Spieltags
    // Anfang 1. Spieltag
    //
    // Bsp: [1] : Anzahl Mannschaften  =  9
    //      [2] : Anzahl Spieltage     = 18
    //      [3] : Spiele / Spieltag    =  4
    // 11 + 9 +  (2 - 1) * (3 + (6 *4)) =  47 : Beginn des 2. Spieltages
    // 11 + 9 + (18 - 1) * (3 + (6 *4)) = 479 : Beginn des 18. Spieltages
    //
    // ***********************************************************************************

    function ZeigeSpieltag($art, $incFile, $anzSpielTage, $strMannschaft)
    {
        // Einstellungsbereich: 0=nein, 1=ja
        // ---------------------------------
        $anzNotiz      = 1;                // Notiz-Anzeige
        $makeShortName = 0;                // Kurze Namen
        $anzFavorit    = 1;                // Favorit-Anzeige
        $anzLink       = 1;                // Anzeige Verlinkung des Spieltags mit der Tabelle
        $anzDatHerv    = 0;                // Anzeige des Datums hervorgehoben:
        $anzVerlSpiele = 1;                // Hervorhebung der verlegten Spiele
        $anzSpielfrei  = 1;                // Spielfreie Mannschaft anzeigen ?
        $anzRahmen     = 0;                // Tabellen-Rahmen

        // Allgemeiner Einstellbereich
        // ---------------------------
        $anzKeineTore  = "-";              // Zeichen fr keine Tore
        $colorVerlSp   = "#D50000";        // Farbe fr Hervorhebung der verlegten Spiele
        $anzHervSt     = "<b><font color='#FF80FF'>";
                                           // Wie wird angezeigt (html) Anfang
        $anzHervEnd    = "</font></b>";
                                           // Wie wird angezeigt (html) Ende
        $PfadLMO       = "../lmo/";        // Pfad zum Script (MIT / am Ende)!
        $designFile   = $PfadLMO . "lmo-ped.css";
                                           // CSS-Datei
        $EndeKennz     = "*";              // Endekennzeichen, welches nicht in den ...
                                           // ... Mannschaftsnamen auftauchen darf zur ...
                                           // ... Kennzeichnung des Dateiendes
                                           
        // Texte fr Spielende offen (Spez in der Liagadatei)
        $arrTxtSp[1]   = "(n.E.)";         // nach Penalty-Schieen
        $arrTxtSp[2]   = "(n.V.)";         // nach Verlngerung

        $anzDatum      = 1;                // Anzeige des Datum-Formats (siehe unten)
        $arrDatForm[0] = "";               // keine
        $arrDatForm[1] = "%d.%m.%Y";       // 24.02.2003
        $arrDatForm[2] = "%d.%m.%y";       // 24.02.03
                                           // usw. hier knnen noch eigene Formate definiert werden
        $anzUhrzeit    = 1;                // Anzeige des Uhrzeit-Formats (siehe unten)
        $arrUhrForm[0] = "";               // keine
        $arrUhrForm[1] = " %H:%M";         // 14:30
        $arrUhrForm[2] = " %H:%M Uhr";     // 14:30 Uhr
                                           // usw. hier knnen noch eigene Formate definiert werden
        // Ende Einstellungsbereich
        // -------------------------------------------------------------------------------------------------

        // ----------------------------------------------------------------------------
        // Allgemeine Variablen -> ab hier nix mehr ndern !!!!!!!
        // ----------------------------------------------------------------------------
        $design       = '<link rel=stylesheet type="text/css" href="' . $designFile . '">';
        $dateShowStr  = chop($arrDatForm[$anzDatum] . $arrUhrForm[$anzUhrzeit]);
    	$tabBreite    = 7 + $anzNotiz;
        $intOffset    = 11;
        $spAnzDaten   = 10;               // Erklrung siehe oben
    	$fClass       = "lmost5";
    	$anfZeile     = "<tr><td  class=" . $fClass . " align=left>";
    	$zwiSpaLi     = "</td><td class=" . $fClass . " align=left>";
    	$zwiSpaZent   = "</td><td class=" . $fClass . " align=center>";
    	$zwiSpaRe     = "</td><td class=" . $fClass . " align=right>";
    	$endZeile     = "</td></tr>";
        $pedVS        = 0.87;
        // Ende allgemeine Variablen
        // ----------------------------------------------------------------------------

        // Keine Anzeige des Datums und Uhrzeit -> $tabBreite - 1
        if ($anzDatum + $anzUhrzeit == 0)
        {
            --$tabBreite;
        } // Ende if ... (Keine Anzeige des Datums und Uhrzeit -> $tabBreite - 1)

        $strMannschaft = strtoupper(chop($strMannschaft));
        // Array fllen:
        // 1 = Einzelmannschaft, $incFile = einzelnes Ergebnis-File
        switch ($art)
        {
            case 1:
            {
                $arrLigaFile[0] = $incFile;
                $arrST          = GetSTData($arrLigaFile[0], $anzSpielTage, $intOffset);
                $arrStart[0]    = 0;
                $arrStart[1]    = sizeof($arrST);
                $arrMannschaft  = array(explode(";", $strMannschaft));
                
                // Nix bergeben -> Alle anzeigen
                if ($strMannschaft == "")
                {
                    $strMannschaft = "ALLE";
                }
            }
            break;
            // 2 = mehrere Mannschaften, $incFile = Datei mit Ligen
            case 2:
            {
                // Liga-File auf einmal einlesen
                $arrFile = file(chop($incFile));
                // Einzelne Liga-Files und Favoriten auslesen
            	for ($i = 0; $i <= sizeof($arrFile); $i++)
                {
                    // Endekennung erreicht ?
                    if (substr($arrFile[$i], 0, 1) == $EndeKennz)
                    {
                        break;
                    } // Ende if ... (Endekennung erreicht ?)

                    // Kommentar ?
                    if (substr($arrFile[$i], 0, 2) != "//")
                    {
                        $ligaPfad = $PfadLMO . substr($arrFile[$i], 0, strpos($arrFile[$i], ";"));
                        // Favoriten, durch ; getrennt, extrahieren
                        $arrMeineMannschaft = explode(";", substr($arrFile[$i], strpos($arrFile[$i], ";") + 1));
                        // Beim 1. Durchlauf -> Arrays anlegen ...
                        if (!is_array($arrLigaFile))
                        {
                            $arrLigaFile = array(chop($ligaPfad));
                            $arrMannschaft = array($arrMeineMannschaft);
                        }
                        else // ... ansonsten -> Arrays verbinden
                        {
                            array_push($arrLigaFile, chop($ligaPfad));
                            array_push($arrMannschaft, $arrMeineMannschaft);
                        } // Ende if ... (Beim 1. Durchlauf -> Array anlegen ...)

                    } // Ende if ... (Kommentar ?)

                } // Ende for ... (Einzelne Liga-Files und Favoriten auslesen)
                // Einlesen der Spielplne in's Ergebnisarray
                $arrStart = array(sizeof($arrLigaFile));
                for ($i = 0; $i < sizeof($arrLigaFile); $i++)
                {
                    $arrStart[$i] = sizeof($arrST);
                    $arrST = array_merge($arrST, GetSTData($arrLigaFile[$i], $anzSpielTage, $intOffset));
                } // Ende for ... Einlesen der Spielplne in's Ergebnisarray
                $arrStart[$i++] = sizeof($arrST);

                if (sizeof($arrMannschaft[0] > 0))
                {
                    $strMannschaften = "";
                }
                break;
            }
        }
        
        for ($i = 0; $i < sizeof($arrMannschaft); $i++)
        {
            for ($j = 0; $j < sizeof($arrMannschaft[$i]); $j++)
            {
                $arrMannschaft[$i][$j] = (int)$arrMannschaft[$i][$j];
            }
        }

        $designFile = $PfadLMO . "lmo-style.css";
        $design     = "<link rel=stylesheet type='text/css' href='" . $designFile . "'>";

        // Ausgabe
        if ($anzSpielTage == 0)
        {
            $titel = "Der aktuelle Spieltag";
        }
        else if ($anzSpielTage == -1)
        {
            $titel = "Der letzte Spieltag";
        }
        else if ($anzSpielTage == 1)
        {
            $titel = "Der nchste Spieltag";
        }
        else if ($anzSpielTage < -1)
        {
            $titel = "Die letzten " . abs($anzSpielTage) . " Spieltage";
        }
        else if ($anzSpielTage > 1)
        {
            $titel = "Die nchsten " . $anzSpielTage . " Spieltage";
        }

        // Spielende offen -> eine Spalte mehr
        if ($arrST[5] == 1)
        {
            ++$tabBreite;
        } // Ende if ... (Spielende offen -> eine Spalte mehr)
        
    	echo $design;
    	// Tabelle
        echo "<table align='center' border=$anzRahmen>";
        // Titel
            echo "<tr>";
                echo "<th colspan=" . $tabBreite . " class=lmomain0>";
                    echo $titel;
                echo "<th>";
            echo "</tr>";
            
            $verlegt = 0;
            // Alle Ligen durchlaufen
            for ($k = 0; $k < sizeof($arrStart); $k++)
            {
                // Variablen
                $spStart    = $arrStart[$k] + $intOffset + $arrST[$arrStart[$k] + 1];
                                                // Ende Header
                $spOffset   = (3 + ($spAnzDaten * $arrST[$arrStart[$k] + 3]));
                                                // Erklrung siehe oben
                // Liganame
                echo "<tr>";
                    echo "<td colspan=" . $tabBreite . " class=lmost4>";
                        echo $arrST[$arrStart[$k]];
                    echo "</td>";
                echo "</tr>";

                // Hauptschleife
                for($i = $spStart; $i < $arrStart[$k + 1]; $i += $spOffset)
                {
                    // Spieltag
                	echo "<tr>";
                        echo "<td  class=" . $fClass . " align=left colspan=" . $tabBreite . ">";

                    		// Tabellen-Link anzeigen ?
                    		if ($anzLink)
                    		{
                                echo "<a href=" . $PfadLMO . "lmo.php?file=" . $arrLigaFile[$k] . "&action=results&st=" . $arrST[$i] . " target='_self' title='Tabelle/Begegnungen des " . $arrST[$i] . ". Spieltages anzeigen'>";
                            } // Ende if ... (Tabellen-Link anzeigen)

                            echo "Spieltag " . $arrST[$i];

                    		// Tabellen-Link anzeigen ?
                    		if ($anzLink)
                    		{
                                echo "</a>";
                            } // Ende if ... (Tabellen-Link anzeigen)

                            echo " - ";

                            // Datum hervorgehoben ?
                            if ($anzDatHerv)
                            {
                                echo $anzHervSt;
                            } // Ende if ... (Datum hervorgehoben ?)

                             echo $arrST[$i + 1];

                            // Datum hervorgehoben ?
                            if ($anzDatHerv)
                            {
                                echo $anzHervEnd;
                            } // Ende if ... (Datum hervorgehoben ?)

                            // 2. Datum
                            if (chop($arrST[$i + 2]) != "")
                            {
                                echo " bis " . $arrST[$i + 2];
                            }  // Ende if ... ( 2. Datum)
                            echo "</b>";
                        echo "<td>";
                    echo "</tr>";

                    // Spielfrei-Template vorbelegen
                    for ($l = 1; $l <= $arrST[$arrStart[$k] + 1]; $l++)
                    {
                        $arrFreiTemplate[$l] = 1;
                    } // Ende for ... (Spielfrei-Template vorbelegen)

                    // Spieltagdurchlauf
                    for ($j = 0; $j < $arrST[$arrStart[$k] + 3]; $j++)
                    {
                        $index    = $i + 2 + ($j * $spAnzDaten);
                        $heimMann = $arrST[$arrStart[$k] + ($intOffset - 1) + $arrST[$index + 1]];
                        $heimID   = (int)$arrST[$index + 1];
                        $gastMann = $arrST[$arrStart[$k] + ($intOffset - 1) + $arrST[$index + 2]];
                        $gastID   = (int)$arrST[$index + 2];
                        $arrFreiTemplate[(int)$arrST[$index + 1]] = 0;
                        $arrFreiTemplate[(int)$arrST[$index + 2]] = 0;
                        
                        // Alle oder einzelne Mannschaften anzeigen
                        if (($strMannschaft == "ALLE" || (in_array($heimID, $arrMannschaft[$k]) || (in_array($gastID, $arrMannschaft[$k])))) && $heimID != 0 && $gastID != 0)
                        {
                            // Anstozeit
                            echo $anfZeile;
                            // Datum wird angezeigt
                            if ($dateShowStr != "")
                            {
                                $dummy = chop((string)date("d.m.Y", $arrST[$index + 6])) != chop((string)$arrST[$i + 1]) && $anzVerlSpiele == 1 && $arrST[$index + 3] == -1 && $arrST[$index + 4] == -1 && isVerlegtST($arrST[$i + 1], $arrST[$index + 6]);
                                if ($dummy)
                                {
                                    echo "<font color=$colorVerlSp>";
                                    $verlegt = 1;
                                }
                            
                                echo strftime($dateShowStr, $arrST[$index + 6]);
                                if ($dummy)
                                {
                                    echo "*</font>";
                                }

                                // Heimmannschaft
                                echo $zwiSpaLi;
                            } // ende if ... (Datum wird angezeigt)
                            $istFavorit = ($arrST[$index + 1] == $arrST[$arrStart[$k] + 4]);
                            // Anzeige des Favoriten
                            if ($anzFavorit && $istFavorit)
                            {
                                echo "<b>";
                            } // Ende if ... (Anzeige des Favoriten)

                            if ($makeShortName == 1)
                            {
                                echo MakeShortName($heimMann);
                            }
                            else
                            {
                                echo $heimMann;
                            }
                            // Anzeige des Favoriten
                            if ($anzFavorit && $istFavorit)
                            {
                                echo "</b>";
                            } // Ende if ... (Anzeige des Favoriten)

                            // -
                            echo $zwiSpaZent . "-";

                            // Gastmannschaft
                            echo $zwiSpaLi;
                            $istFavorit = ($arrST[$index + 2] == $arrST[$arrStart[$k] + 4]);
                            // Anzeige des Favoriten
                            if ($anzFavorit && $istFavorit)
                            {
                                echo "<b>";
                            } // Ende if ... (Anzeige des Favoriten)

                            if ($makeShortName == 1)
                            {
                                echo MakeShortName($gastMann);
                            }
                            else
                            {
                                echo $gastMann;
                            }
                            // Anzeige des Favoriten
                            if ($anzFavorit && $istFavorit)
                            {
                                echo "</b>";
                            } // Ende if ... (Anzeige des Favoriten)

                            // Heimtore
                            echo $zwiSpaRe;
                            if ($arrST[$index + 3] != -1)
                            {
                                $heimTore = $arrST[$index + 3];
                            }
                            else
                            {
                                $heimTore = $anzKeineTore;
                            }
                            echo $heimTore;

                            // :
                            echo $zwiSpaZent . ":";

                            // Gasttore
                            echo $zwiSpaRe;
                            if ($arrST[$index + 4] != -1)
                            {
                                $gastTore = $arrST[$index + 4];
                            }
                            else
                            {
                                $gastTore =  $anzKeineTore;
                            }
                            echo $gastTore;

                            // Spielende offen -> eine Spalte mehr
                            if ($arrST[5] == 1)
                            {
                                echo $zwiSpaZent;
                            }

                            // Ende nach Penaltyschieen oder Verlngerung
                            if ($arrST[$index + 7] != 0)
                            {
                                echo $arrTxtSp[$arrST[$index + 7]];
                            }
                            else
                            {
                                echo "&nbsp;";
                            } // Ende if ...(Ende nach Penaltyschieen oder Verlngerung)

                            // Notiz
                            if ($anzNotiz == 1)
                            {
                                echo $zwiSpaLi;
                                if (chop($arrST[$index + 5]) != "")
                                {
                                    $text = chop($heimMann) . " - " . chop($gastMann) . " " . chop($heimTore) . " : " . chop($gastTore);
                                    $text .= "\\n\\nNOTIZ:\\n" . chop($arrST[$index + 5]);
                                    echo "<a href=\"javascript:alert('" . $text . "');\" title=\"" . str_replace("\\n", "&#10;", $text) . "\">";
                                    echo "<image src='../lmo/lmo-st2.gif' border='0'>";
                                    echo "</a>";
                                }
                                else
                                {
                                    echo "&nbsp;";
                                }
                            } // Ende if ... (Notiz)

                            echo $endZeile;
                        } // Ende if ... (Alle oder einzelne Mannschaften anzeigen)
                    } // Ende for ... (Spieltagdurchlauf)

                    // Anzeige Spielfrei ?
                    if ($anzSpielfrei == 1)
                    {
                        // Spielfrei - Schleife
                        for ($l = 1; $l <= $arrST[$arrStart[$k] + 1]; $l++)
                        {
                            if ($arrFreiTemplate[$l] == 1)
                            {
                            	echo "<tr><td  class=" . $fClass . " align=left colspan=" . $tabBreite . ">";
                            	    echo "Spielfrei: ";
           	                        // Favorit ?
                                    if ($l == $arrST[$arrStart[$k] + 4])   { echo "<b>"; }
                                    echo $arrST[$arrStart[$k] + ($intOffset - 1) + $l];
              	                    // Favorit ?
                                    if ($l == $arrST[$arrStart[$k] + 4])   { echo "</b>"; }
                                echo $endZeile;
                                echo "</tr>";
                            }
                        } // Ende for ... (Spielfrei - Schleife)
                    } // Ende if ... (Anzeige Spielfrei ?)
                }  // Ende for ... (Hauptschleife)
            } // Ende for ... (Alle Ligen durchlaufen)

            // Anzeige verlegter Spiele ?
            if ($anzVerlSpiele == 1 && $verlegt == 1)
            {
                echo $anfZeile;
                    echo "<font color=$colorVerlSp>";
                        echo "* verlegte Spiele";
                    echo "</font>";
                echo $endZeile;
            } // Ende if ... (Anzeige verlegter Spiele ?)
            // Copyrights
            echo "<tr>";
                echo "<td colspan=" . $tabBreite . " class=lmomain2 align=center>";
                    echo "<style='font-size:2px'>";
                    echo "<a href='http://www.peterscherb.de/svj' target='_blank'>";
                    echo "LMO-Spieltag V " . $pedVS;
                    echo "</a> &copy; " . date("m") . "/" . date("Y") . " <a href='mailto:Peter.Scherb@PeterScherb.de'>";
                    echo "eMehl an Ped</a>";
                echo "</td>";
            echo "</tr>";
        echo "</table>";
    }


    // ------------------------------------------------------------------------------------------------
    function GetSTData($LigaFile, $anzSpielTage, $intOffset)
    {
        // Datei komplett einlesen
    	$arrFile       = file($LigaFile);
        $sizeOfArrFile = sizeof($arrFile);
        $spCounter     = $intOffset;          // laufender Zhler des Ergebnis-Arrays
        $SpielTag      = 1;                    // laufender Zhler der Spieltage
        
        for($i = 0; $i <= $intOffset; $i++)
        {
            $arrST[$i] = 0;
        }

        // "Header" einlesen
    	for ($i = 0; $i < $sizeOfArrFile; $i++)
        {
            $arrFile[$i] = chop($arrFile[$i]);
    		
    		// Name der Liga merken
    		if (GetSTKey($arrFile[$i]) == "Name")
            {
                $arrST[0] = GetSTValue($arrFile[$i]);
            } // Ende if ... (Name der Liga merken)
    		
            // Anzahl der Mannschaften
    		if (GetSTKey($arrFile[$i]) == "Teams")
    		{
                $arrST[1] = (int)GetSTValue($arrFile[$i]);
            } // Ende if ... (Anzahl der Mannschaften)
            
            // Anzahl der Spieltage
    		if (GetSTKey($arrFile[$i]) == "Rounds")
    		{
                $arrST[2] = (int)GetSTValue($arrFile[$i]);
            }
            // Ende if ... (Anzahl der Spieltage)
            
            // Anzahl der Begegnungen / Spieltage
    		if (GetSTKey($arrFile[$i]) == "Matches")
    		{
                $arrST[3] = (int)GetSTValue($arrFile[$i]);
            }
            // Ende if ... (Anzahl Begegnungen / Spieltage)

            // Aktueller Spieltag
    		if (GetSTKey($arrFile[$i]) == "Actual")
    		{
                $aktuell = (int)GetSTValue($arrFile[$i]);
            }
            // Ende if ... (Aktueller Spieltag)

            // favTeam merken
    		if (GetSTKey($arrFile[$i]) == "favTeam")
    		{
                $arrST[4] = (int)GetSTValue($arrFile[$i]);
            } // Ende if ... (favTeam merken)

            // Spez merken
    		if (GetSTKey($arrFile[$i]) == "Spez")
    		{
                $arrST[5] = (int)GetSTValue($arrFile[$i]);
            } // Ende if ... (Spez merken)

            // Teams einlesen
            if ($arrFile[$i] == "[Teams]")
            {
                $i++;
                for ($j = 1; $j <= $arrST[1]; $j++)
                {
                    $arrST[$spCounter++] = GetSTValue($arrFile[$i++]);
                }
            } // Ende if ... (Teams einlesen)

    		// hat die Spieltag-Sektion erreicht -> raus
            if ($arrFile[$i] == "[Round1]")
            {
                $lenOfEmptyArray = sizeof($arrST);
                break;
            } // Ende if ... (hat die Spieltag-Sektion erreicht -> raus)

        } // Ende for ... ("Header" einlesen)
        // 1. Array-Element vorbelegen
        $arrInterval[0] = -1;
        if ($anzSpielTage < 0)
        {
            // Schleife anzuzeigende Spieltags-Nr. vorher
            for ($j = 0; $j > $anzSpielTage ; $j--)
            {
                $arrInterval[$j] = $aktuell + $j - 1;
            } // Ende for ... (Schleife anzuzeigende Spieltags-Nr. vorher)
        }
        else if ($anzSpielTage > 0)
        {
            // Schleife anzuzeigende Spieltags-Nr. nachher
            for ($j = 0; $j < $anzSpielTage ; $j++)
            {
                $arrInterval[$j] = $aktuell + $j + 1;
            } // Ende for ... (Schleife anzuzeigende Spieltags-Nr. nachher)
        }
        else if ($anzSpielTage == 0)
        {
            $arrInterval[0] = $aktuell;
        }

        $intSP = 0;
        // Schleife Spieltage
        for ($spTag = $i; $spTag < $sizeOfArrFile; $spTag++)
        {
    		// Nchste Runde erreicht ?
			if (substr($arrFile[$spTag], 0, 6) == "[Round")
            {
                $arrFile[$spTag] = chop($arrFile[$spTag]);
                $SpielTag = substr($arrFile[$spTag], 6);
                $SpielTag = substr($SpielTag, 0, strlen($spielTag) - 1);
                // Ist das Datum leer -> nicht eintragen
        		//$value = substr($arrFile[$spTag + 1], strpos($arrFile[$spTag + 1], "=") + 1);
        		$datum1 = chop(GetSTValue($arrFile[$spTag + 1]));
                if ($datum1 != "")
                // if (chop($value) != "")
                {
				    $flLeer = false;
                    // Spieltag im Interval ?
                    if (in_array($SpielTag, $arrInterval))
                    {
        				$arrST[$spCounter++] = $SpielTag;
                    } // Ende if ... (Spieltag im Interval ?)
        			$spTag++;
     			}
     			else
     			{
     			    $flLeer = true;
                }
			} // Ende if ... (Nchste Runde erreicht ?)

            // Spieltag im Interval ?
            if (in_array($SpielTag, $arrInterval))
            {
                // Schlel
        		$key = substr($arrFile[$spTag], 0, 2);
        		// Wert
        		$value = chop(substr($arrFile[$spTag], strpos($arrFile[$spTag], "=") + 1));

                if ($key == "SP")
                {
                    $intSP = (int)$value;
                }
                // Keys, die bersprungen werden
    			if (!(strpos($arrFile[$spTag], "=") == 0 || $key == "HS" || $key == "MO" || $key == "SP" || $key == "ET" || $key == "BE" || $key == "TI"))
    			{
                    // Leere Spieltage berspringen			
                    if (!$flLeer)
                    {
                        // Letzter Schleleintrag
                        if ($key == "AT")
                        {
                            if ((int)$value != 0)
                            {
                                $arrST[$spCounter++] = $value;
                            }
                            // AT leer ?
                            else
                            {
                                $arrST[$spCounter++] = DateStrToUnixST($datum1);
                            }
                            // Reserviert belegen
                            $arrST[$spCounter++] = $intSP;
                            $arrST[$spCounter++] = 0;
                            $arrST[$spCounter++] = 0;
                            $arrST[$spCounter++] = 0;
                        } // Ende if ... (Letzter Schleleintrag)
                        else
                        {
                            $arrST[$spCounter++] = $value;
                        }
                    } // Ende if ... (Leere Spieltage berspringen)
                    
                } // Ende if ... (Keys, die bersprungen werden)
            } // Ende if ... (Spieltag im Interval ?)

        } // Ende for ... (Schleife Spieltage)
        
        return $lenOfEmptyArray == sizeof($arrST) ? "" : $arrST;
    }


    function GetSTKey($xVar)
    {
        return (substr($xVar, 0, strpos($xVar, "=")));
    }


    function GetSTValue($xVar)
    {
        return (substr($xVar, strpos($xVar, "=") + 1));
    }
    
    function DateStrToUnixST($dateString)
    {
        $arr = explode(".", $dateString);
        return mktime(0, 0, 0, $arr[1], $arr[0], $arr[2]);
    }


    // Checkt, ob Spielverlegt wurde, Algorithmus aus lmo_spieleverlegung.php
    function isVerlegtST($dateString, $anStZeit)
    {
        // $dateString zerlegen und umwandeln
        $arrDate    = explode(".", chop($dateString));
        $arrGetDate = getdate(mktime(0, 0, 0, $arrDate[1], $arrDate[0], $arrDate[2]));
        // Kalenderwoche von $dateString
        $week1 = strftime("%W", mktime(0, 0, 0, $arrDate[1], $arrDate[0], $arrDate[2]));
        // Wochentag von $dateString
        $weekDay1 = $arrGetDate[wday];
        // Woche des AT-Datums
        $week2 = strftime("%W", $anStZeit);
        // Wochentag des AT-Datums
        $weekDay2 = date("w", $anStZeit);

        $flVerlegt = false;
        if (chop($dateString) != (string)chop(date("d.m.Y", $anStZeit)))
        {
            if ($week1 != $week2)
            {
                $flVerlegt = true;
            }
            else if ($week1 == $week2)
            {
                if (($weekDay1 >= 5 || $weekDay1 == 0) && $weekDay2 < 5 && $weekDay2 !=0)
                {
                    $flVerlegt = true;
                }
                else if ($weekDay1 < 5 &&  $weekDay1 !=0)
                {
                    $flVerlegt = true;
                }
            }
        }
        return $flVerlegt;
  }

    // Generiert Kurznamen
    function MakeShortName($name)
    {
        // -------------------------------------------------------------
        // Hier knnen noch weitere Ausschlukriterien angegeben werden.
        $arrAusschluss = Array("TSV", "VFL", "1.FC", "1. FC", "HSG", "SSV");
        // -------------------------------------------------------------

        // String in Array
        $arrErgeb = explode(" ", $name);

        // Array durchlaufen
        for($i = 0; $i < sizeof($arrErgeb); $i++)
        {
            // Ausschlu-Array
            if (in_array(strtoupper($arrErgeb[$i]), $arrAusschluss))
            {
                array_splice($arrErgeb, $i, 1);
            }

            // Lnge
            if (strlen($arrErgeb[$i]) <= 2)
            {
                array_splice($arrErgeb, $i, 1);
            }
        } // Ende for ... (Array durchlaufen)

        // Sortieren
        usort($arrErgeb, "vglFunc");
        // 1. Array-Element zurck
        return $arrErgeb[0];
    }


    function vglFunc($a, $b)
    {
        // Numerische Werte nach oben, wenn nicht gewnscht -> auskommentieren und
        // else wech
        if (is_numeric($b)) { return($b < $a); }
        // Lngere String zuerst, dann unteres auskommentieren
        else                { return(strlen($a) < strlen($b)); }
        // krzere String zuerst, dann obiges auskommentieren
        // else                { return(strlen($a) > strlen($b)); }
    }
?>